@@ -251,11 +251,12 @@ class Experiment:
             logger.info('No existing image found')
             self.build_experiment_image(path=self.project_path)
         else:
-            logger.info('Found existing project image')
+            logger.info(f'Found existing project image: {self.experiment_name}:latest')
 
         logger.debug(f'Artifact URI: {mlflow.get_artifact_uri()}')
+        logger.debug(f'Project URI: {self.project_path}')
 
-        mlflow.run(self.project_path,
+        mlflow.run(uri=self.project_path,
                    experiment_id=self.experiment_id,
                    use_conda=False,
                    **kwargs)
