@@ -17,7 +17,7 @@ class LoadImageXNATd(MapTransform):
     """
 
     def __init__(self, keys: KeysCollection, actions: list = None, xnat_configuration: dict = None,
-                 image_loader: Transform = LoadImage, validate_data: bool = False, expected_filetype_ext: str = '.dcm'):
+                 image_loader: Transform = LoadImage(), validate_data: bool = False, expected_filetype_ext: str = '.dcm'):
         super().__init__(keys)
         self.image_loader = image_loader
         self.xnat_configuration = xnat_configuration
@@ -73,7 +73,7 @@ class LoadImageXNATd(MapTransform):
                             xnat_obj = None
 
                         if self.validate_data:
-                            if xnat_obj is not None:
+                            if len(xnat_obj) > 0:
                                 d[data_label] = True
                                 return d
                             else:
@@ -82,22 +82,32 @@ class LoadImageXNATd(MapTransform):
 
                         with tempfile.TemporaryDirectory() as tmpdirname:
                             "download image from XNAT"
-                            session_obj = session.create_object(xnat_obj.uri)
-                            session_obj.download_dir(tmpdirname)
+                            # data = []
+                            for obj in xnat_obj:
 
-                            images_path = glob.glob(os.path.join(tmpdirname, '**/*' + self.expected_filetype), recursive=True)
+                                session_obj = session.create_object(obj.uri)
+                                session_obj.download_dir(tmpdirname)
 
-                            "find unique directories in list of image paths"
-                            image_dirs = list(set(os.path.dirname(image_path) for image_path in images_path))
+                                images_path = glob.glob(os.path.join(tmpdirname, '**/*' + self.expected_filetype), recursive=True)
 
-                            if len(image_dirs) > 1:
-                                raise ValueError(f'More than one image series found in {images_path}')
+                                # image loader needs full path to load single images
+                                logger.info(f"Downloading images: {images_path}")
+                                if len(images_path) == 1:
+                                    image, meta = self.image_loader(images_path)
 
-                            logger.info(f"Downloading image: {image_dirs[0]}")
+                                # image loader needs directory path to load 3D images
+                                else:
+                                    "find unique directories in list of image paths"
+                                    image_dirs = list(set(os.path.dirname(image_path) for image_path in images_path))
+                                    if len(image_dirs) > 1:
+                                        raise ValueError(f'More than one image series found in {images_path}')
 
-                            image, meta = self.image_loader()(image_dirs[0])
+                                    image, meta = self.image_loader(image_dirs[0])
+
+                                # data.append(image, meta)
 
                             d[data_label] = image
                             d[data_label + '_meta'] = meta
+                            d[data_label + '_xnat_uri'] = session_obj.fulluri
 
             return d
